﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;

namespace MultipleDotDensityStyles
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //Case 1: One FeatureLayer with two DotDensityStyles
            LoadOneLayerWithTwoStyles();

            //Case 2: Two FeatureLayers with one DotDensityStyle each
            LoadTwoLayersWithOneStyleEach();

        }


        private void LoadOneLayerWithTwoStyles()
        {
            winformsMap1.MapUnit = GeographyUnit.DecimalDegree;
            winformsMap1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean);

            ShapeFileFeatureLayer statesLayer = new ShapeFileFeatureLayer(@"../../data/USStates.shp");
            statesLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            statesLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(new AreaStyle(new GeoPen(GeoColor.StandardColors.Black, 1), new GeoSolidBrush(GeoColor.StandardColors.LightGray)));

            DotDensityStyle dotDensityStyle = new DotDensityStyle();
            dotDensityStyle.ColumnName = "AGE_18_64";
            dotDensityStyle.PointToValueRatio = 0.000001; // (1 / 100,000) = 0.00001
            dotDensityStyle.CustomPointStyle = new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColor.FromArgb(180, GeoColor.StandardColors.OrangeRed)), 6);
            statesLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(dotDensityStyle);

            DotDensityStyle dotDensityStyle1 = new DotDensityStyle();
            dotDensityStyle1.ColumnName = "AGE_65_UP";
            dotDensityStyle1.PointToValueRatio = 0.000005; // (1 / 100,000) = 0.00001
            dotDensityStyle1.CustomPointStyle = new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColor.FromArgb(180, GeoColor.StandardColors.Green)), 6);
            statesLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(dotDensityStyle1);

            LayerOverlay layerOverlay = new LayerOverlay();
            layerOverlay.Layers.Add("States", statesLayer);
            winformsMap1.Overlays.Add("Overlay", layerOverlay);

            statesLayer.Open();
            winformsMap1.CurrentExtent = statesLayer.GetBoundingBox();
            statesLayer.Close();

            winformsMap1.Refresh();
        }

        private void LoadTwoLayersWithOneStyleEach()
        {
            winformsMap2.MapUnit = GeographyUnit.DecimalDegree;
            winformsMap2.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean);

            ShapeFileFeatureLayer statesLayer = new ShapeFileFeatureLayer(@"../../data/USStates.shp");
            statesLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            statesLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(new AreaStyle(new GeoPen(GeoColor.StandardColors.Black, 1), new GeoSolidBrush(GeoColor.StandardColors.LightGray)));

            DotDensityStyle dotDensityStyle = new DotDensityStyle();
            dotDensityStyle.ColumnName = "AGE_18_64";
            dotDensityStyle.PointToValueRatio = 0.000001; // (1 / 100,000) = 0.00001
            dotDensityStyle.CustomPointStyle = new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColor.FromArgb(180, GeoColor.StandardColors.OrangeRed)), 6);
            statesLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(dotDensityStyle);


            ShapeFileFeatureLayer statesLayer1 = (ShapeFileFeatureLayer)statesLayer.CloneDeep();

            DotDensityStyle dotDensityStyle1 = new DotDensityStyle();
            dotDensityStyle1.ColumnName = "AGE_65_UP";
            dotDensityStyle1.PointToValueRatio = 0.000005; // (1 / 100,000) = 0.00001
            dotDensityStyle1.CustomPointStyle = new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColor.FromArgb(180, GeoColor.StandardColors.Green)), 6);
            statesLayer1.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(dotDensityStyle1);

            LayerOverlay layerOverlay = new LayerOverlay();
            layerOverlay.Layers.Add("States", statesLayer);
            layerOverlay.Layers.Add("States1", statesLayer1);
            winformsMap2.Overlays.Add("Overlay", layerOverlay);

            statesLayer.Open();
            winformsMap2.CurrentExtent = statesLayer.GetBoundingBox();
            statesLayer.Close();

            winformsMap2.Refresh();
        }

        private void winformsMap1_CurrentExtentChanged(object sender, CurrentExtentChangedWinformsMapEventArgs e)
        {
            winformsMap2.CurrentExtent = e.CurrentExtent;
            winformsMap2.Refresh();
        }

        private void winformsMap2_CurrentExtentChanged(object sender, CurrentExtentChangedWinformsMapEventArgs e)
        {
            winformsMap1.CurrentExtent = e.CurrentExtent;
            winformsMap1.Refresh();
        }
    }
}
